@@ -40,6 +40,11 @@ struct isDouble<double>{
 #include <R_ext/Print.h>
 #include "Rstream.hpp"
 
+/* Flag to bypass abort() */
+#ifndef TMB_ABORT
+#define TMB_ABORT abort()
+#endif
+
 /* Include the Eigen library. */
 #ifdef TMB_SAFEBOUNDS
 #undef NDEBUG
@@ -50,14 +55,14 @@ void eigen_REprintf(const char* x);
                                   eigen_REprintf(#x);                                                \
                                   eigen_REprintf("\nPlease check your matrix-vector bounds etc., "); \
                                   eigen_REprintf("or run your program through a debugger.\n");       \
-				  abort();}
+				  TMB_ABORT;}
 #define TMBAD_ASSERT2(x,msg)                                            \
 if (!(x)) {                                                             \
   Rcerr << "TMBad assertion failed.\n";                                 \
   Rcerr << "The following condition was not met: " << #x << "\n";       \
   Rcerr << "Possible reason: " msg << "\n";                             \
   Rcerr << "For more info run your program through a debugger.\n";      \
-  abort();                                                              \
+  TMB_ABORT;                                                            \
 }
 #define TMBAD_ASSERT(x) TMBAD_ASSERT2(x,"Unknown")
 #else
@@ -113,6 +118,7 @@ using SparseMatrix = SparseMatrix_rename<T, Flags, StorageIndex>;
 #include "TMBad/compile.hpp"
 #include "TMBad/graph2dot.hpp"
 #include "TMBad/compression.hpp"
+#include "TMBad/ad_blas.hpp"
 #ifndef WITH_LIBTMB
 #include "TMBad/TMBad.cpp"
 #endif
@@ -157,9 +163,10 @@ namespace TMBad {
 #include <R.h>
 #include <Rinternals.h>
 #include "toggle_thread_safe_R.hpp"
-void eigen_REprintf(const char* x)CSKIP({REprintf(x);})
+void eigen_REprintf(const char* x)CSKIP({REprintf("%s",x);})
 
 #include "tmbutils/tmbutils.hpp"
+#include "tmbutils/vectorize.hpp"
 using tmbutils::matrix;
 using tmbutils::vector;
 using CppAD::AD;
@@ -197,6 +204,8 @@ namespace CppAD{
 #include "convenience.hpp"    // Requires besselK
 #include "tmbutils/tmbutils_extra.hpp"
 #include "tmbutils/R_inla.hpp"
+#include "tmbutils/sparse_matrix_exponential.hpp"
+#include "tmbutils/concat.hpp"
 #include "precompile.hpp" // Must come last
 using tmbutils::array;
 using Eigen::Matrix;
